==> DateTime-Locale-1.35.tar.gz: DateTime-Locale-1.35/share/eo-001.pl <==
{
  am_pm_abbreviated => [
    "atm",
    "ptm",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d, E",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "G y MMM d, E",
    GyMMMd => "G y MMM d",
    GyMd => "GGGGG y-MM-dd",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "MM-dd, E",
    MMM => "LLL",
    MMMEd => "MMM d, E",
    "MMMMW-count-other" => "'week' W 'of' MMMM",
    MMMMd => "MMMM d",
    MMMd => "MMM d",
    Md => "MM-dd",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "y-MM",
    yMEd => "y-MM-dd, E",
    yMMM => "y MMM",
    yMMMEd => "y MMM d, E",
    yMMMM => "y MMMM",
    yMMMd => "y MMM d",
    yMd => "y-MM-dd",
    yQQQ => "y QQQ",
    yQQQQ => "y QQQQ",
    "yw-count-other" => "'week' w 'of' Y",
  },
  code => "eo-001",
  date_format_full => "EEEE, d-'a' 'de' MMMM y",
  date_format_long => "y-MMMM-dd",
  date_format_medium => "y-MMM-dd",
  date_format_short => "yy-MM-dd",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "lu",
    "ma",
    "me",
    "\N{U+0135}a",
    "ve",
    "sa",
    "di",
  ],
  day_format_narrow => [
    "M",
    "T",
    "W",
    "T",
    "F",
    "S",
    "S",
  ],
  day_format_wide => [
    "lundo",
    "mardo",
    "merkredo",
    "\N{U+0135}a\N{U+016d}do",
    "vendredo",
    "sabato",
    "diman\N{U+0109}o",
  ],
  day_stand_alone_abbreviated => [
    "lu",
    "ma",
    "me",
    "\N{U+0135}a",
    "ve",
    "sa",
    "di",
  ],
  day_stand_alone_narrow => [
    "M",
    "T",
    "W",
    "T",
    "F",
    "S",
    "S",
  ],
  day_stand_alone_wide => [
    "lundo",
    "mardo",
    "merkredo",
    "\N{U+0135}a\N{U+016d}do",
    "vendredo",
    "sabato",
    "diman\N{U+0109}o",
  ],
  era_abbreviated => [
    "aK",
    "pK",
  ],
  era_narrow => [
    "aK",
    "pK",
  ],
  era_wide => [
    "aK",
    "pK",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %d %b %Y %T %z",
  glibc_date_format => "%Y-%m-%d",
  glibc_datetime_format => "%a %d %b %Y %T",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%T",
  language => "Esperanto",
  month_format_abbreviated => [
    "jan",
    "feb",
    "mar",
    "apr",
    "maj",
    "jun",
    "jul",
    "a\N{U+016d}g",
    "sep",
    "okt",
    "nov",
    "dec",
  ],
  month_format_narrow => [
    1,
    2,
    3,
    4,
    5,
    6,
    7,
    8,
    9,
    10,
    11,
    12,
  ],
  month_format_wide => [
    "januaro",
    "februaro",
    "marto",
    "aprilo",
    "majo",
    "junio",
    "julio",
    "a\N{U+016d}gusto",
    "septembro",
    "oktobro",
    "novembro",
    "decembro",
  ],
  month_stand_alone_abbreviated => [
    "jan",
    "feb",
    "mar",
    "apr",
    "maj",
    "jun",
    "jul",
    "a\N{U+016d}g",
    "sep",
    "okt",
    "nov",
    "dec",
  ],
  month_stand_alone_narrow => [
    1,
    2,
    3,
    4,
    5,
    6,
    7,
    8,
    9,
    10,
    11,
    12,
  ],
  month_stand_alone_wide => [
    "januaro",
    "februaro",
    "marto",
    "aprilo",
    "majo",
    "junio",
    "julio",
    "a\N{U+016d}gusto",
    "septembro",
    "oktobro",
    "novembro",
    "decembro",
  ],
  name => "Esperanto world",
  native_language => "esperanto",
  native_name => "esperanto Mondo",
  native_script => undef,
  native_territory => "Mondo",
  native_variant => undef,
  quarter_format_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_stand_alone_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  script => undef,
  territory => "world",
  time_format_full => "H-'a' 'horo' 'kaj' m:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 41,
}

==> DateTime-Locale-1.41.tar.gz: DateTime-Locale-1.41/share/eo-001.pl <==
{
  am_pm_abbreviated => [
    "atm",
    "ptm",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d, E",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "G y MMM d, E",
    GyMMMd => "G y MMM d",
    GyMd => "GGGGG y-MM-dd",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "MM-dd, E",
    MMM => "LLL",
    MMMEd => "MMM d, E",
    "MMMMW-count-other" => "'week' W 'of' MMMM",
    MMMMd => "MMMM d",
    MMMd => "MMM d",
    Md => "MM-dd",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "y-MM",
    yMEd => "y-MM-dd, E",
    yMMM => "y MMM",
    yMMMEd => "y MMM d, E",
    yMMMM => "y MMMM",
    yMMMd => "d MMM y",
    yMd => "y-MM-dd",
    yQQQ => "y QQQ",
    yQQQQ => "y QQQQ",
    "yw-count-other" => "'week' w 'of' Y",
  },
  code => "eo-001",
  date_format_full => "EEEE, 'la' d-'a' 'de' MMMM y",
  date_format_long => "y-MMMM-dd",
  date_format_medium => "y-MMM-dd",
  date_format_short => "yy-MM-dd",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "lu",
    "ma",
    "me",
    "\N{U+0135}a",
    "ve",
    "sa",
    "di",
  ],
  day_format_narrow => [
    "M",
    "T",
    "W",
    "T",
    "F",
    "S",
    "S",
  ],
  day_format_wide => [
    "lundo",
    "mardo",
    "merkredo",
    "\N{U+0135}a\N{U+016d}do",
    "vendredo",
    "sabato",
    "diman\N{U+0109}o",
  ],
  day_stand_alone_abbreviated => [
    "lu",
    "ma",
    "me",
    "\N{U+0135}a",
    "ve",
    "sa",
    "di",
  ],
  day_stand_alone_narrow => [
    "M",
    "T",
    "W",
    "T",
    "F",
    "S",
    "S",
  ],
  day_stand_alone_wide => [
    "lundo",
    "mardo",
    "merkredo",
    "\N{U+0135}a\N{U+016d}do",
    "vendredo",
    "sabato",
    "diman\N{U+0109}o",
  ],
  era_abbreviated => [
    "a.n.e.",
    "n.e.",
  ],
  era_narrow => [
    "a.n.e.",
    "n.e.",
  ],
  era_wide => [
    "anta\N{U+016d} nia erao",
    "de nia erao",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %d %b %Y %T %z",
  glibc_date_format => "%Y-%m-%d",
  glibc_datetime_format => "%a %d %b %Y %T",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%T",
  language => "Esperanto",
  month_format_abbreviated => [
    "Jan",
    "Feb",
    "Mar",
    "Apr",
    "Maj",
    "Jun",
    "Jul",
    "A\N{U+016d}g",
    "Sep",
    "Okt",
    "Nov",
    "Dec",
  ],
  month_format_narrow => [
    1,
    2,
    3,
    4,
    5,
    6,
    7,
    8,
    9,
    10,
    11,
    12,
  ],
  month_format_wide => [
    "Januaro",
    "Februaro",
    "Marto",
    "Aprilo",
    "Majo",
    "Junio",
    "Julio",
    "A\N{U+016d}gusto",
    "Septembro",
    "Oktobro",
    "Novembro",
    "Decembro",
  ],
  month_stand_alone_abbreviated => [
    "Jan",
    "Feb",
    "Mar",
    "Apr",
    "Maj",
    "Jun",
    "Jul",
    "A\N{U+016d}g",
    "Sep",
    "Okt",
    "Nov",
    "Dec",
  ],
  month_stand_alone_narrow => [
    1,
    2,
    3,
    4,
    5,
    6,
    7,
    8,
    9,
    10,
    11,
    12,
  ],
  month_stand_alone_wide => [
    "Januaro",
    "Februaro",
    "Marto",
    "Aprilo",
    "Majo",
    "Junio",
    "Julio",
    "A\N{U+016d}gusto",
    "Septembro",
    "Oktobro",
    "Novembro",
    "Decembro",
  ],
  name => "Esperanto world",
  native_language => "Esperanto",
  native_name => "Esperanto mondo",
  native_script => undef,
  native_territory => "mondo",
  native_variant => undef,
  quarter_format_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_stand_alone_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  script => undef,
  territory => "world",
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => "44.1",
}
